==> foundry_platform_sdk-0.35.0.tar.gz: foundry_platform_sdk-0.35.0/foundry/v2/aip_agents/models/_cancel_session_response.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Optional
from typing import cast

import pydantic

from foundry.v2.aip_agents.models._cancel_session_response_dict import (
    CancelSessionResponseDict,
)  # NOQA
from foundry.v2.aip_agents.models._session_exchange_result import SessionExchangeResult


class CancelSessionResponse(pydantic.BaseModel):
    """CancelSessionResponse"""

    result: Optional[SessionExchangeResult] = None
    """
    If the `response` field was specified, this returns the result that was added to the session
    for the canceled exchange, with the client-provided response.
    If no `response` was specified in the request, this returns an empty response as no exchange
    was added to the session.
    """

    model_config = {"extra": "allow"}

    def to_dict(self) -> CancelSessionResponseDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(CancelSessionResponseDict, self.model_dump(by_alias=True, exclude_unset=True))

==> foundry_platform_sdk-0.43.0.tar.gz: foundry_platform_sdk-0.43.0/foundry/v2/aip_agents/models/_cancel_session_response.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import Optional
from typing import cast

import pydantic

from foundry.v2.aip_agents.models._cancel_session_response_dict import (
    CancelSessionResponseDict,
)  # NOQA
from foundry.v2.aip_agents.models._session_exchange_result import SessionExchangeResult


class CancelSessionResponse(pydantic.BaseModel):
    """CancelSessionResponse"""

    result: Optional[SessionExchangeResult] = None
    """
    If the `response` field was specified, this returns the result that was added to the session for the canceled exchange, with the client-provided response.
    If no `response` was specified in the request, this returns an empty response, as no exchange was added to the session.
    """

    model_config = {"extra": "allow"}

    def to_dict(self) -> CancelSessionResponseDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(CancelSessionResponseDict, self.model_dump(by_alias=True, exclude_unset=True))
